@@ -63,8 +63,8 @@ debit_table <- function(x, sd, n,
 
   # Count decimal places of the standard deviation (SD) and the distribution
   # mean, both as reported:
-  digits_x  <- decimal_places(x)
-  digits_sd <- decimal_places(sd)
+  digits_x  <- decimal_places_scalar(x)
+  digits_sd <- decimal_places_scalar(sd)
 
   sd_chr <- sd
   x_chr <- x
@@ -77,7 +77,7 @@ debit_table <- function(x, sd, n,
   # Recover lower and upper bounds for the original mean and SD values using
   # `unround()`, going by the reported value each time and defining values out
   # of the tibble resulting from that call. First, the mean...
-  x_unrounded   <- suppressMessages(unround(
+  x_unrounded <- suppressMessages(unround(
     x_chr, rounding = rounding, threshold = threshold, digits = digits_x
   ))
   x_upper       <- x_unrounded$upper
@@ -94,6 +94,8 @@ debit_table <- function(x, sd, n,
   sd_incl_lower <- sd_unrounded$incl_lower
   sd_incl_upper <- sd_unrounded$incl_upper
 
+  rm(x_unrounded, sd_unrounded)
+
   # Reconstruct the original SD:
   sd_rec_lower <- reconstruct_sd(formula, x_lower, n)  # ADD `group_0, group_1` TO SUPPORT OTHER FORMULAS
   sd_rec_upper <- reconstruct_sd(formula, x_upper, n)  # ADD `group_0, group_1` TO SUPPORT OTHER FORMULAS
@@ -148,15 +150,13 @@ debit_table <- function(x, sd, n,
   # (rounding method, boundary values, and Boolean information about the
   # boundary values being inclusive or not):
   if (show_rec) {
-    out <- tibble::tibble(
+    tibble::tibble(
       sd = sd_chr, x = x_chr, n, consistency, rounding,
       sd_lower, sd_incl_lower, sd_incl_upper, sd_upper,
       x_lower, x_incl_lower, x_upper, x_incl_upper
     )
-    return(out)
   } else {
-    out <- tibble::tibble(sd = sd_chr, x = x_chr, n, consistency)
-    return(out)
+    tibble::tibble(sd = sd_chr, x = x_chr, n, consistency)
   }
 
 }
