@@ -4,8 +4,8 @@
 #' @export
 
 audit.scr_audit_total_n <- function(data) {
-  summarize_audit_special(
-    data, selector = c(
+  audit_summary_stats(
+    data, selection = c(
       "hits_total", "hits_forth", "hits_back", "scenarios_total", "hit_rate"
     )
   )
