@@ -4,7 +4,7 @@
 
 audit.scr_grimmer_map <- function(data) {
   out <- audit_cols_minimal(data, "GRIMMER")
-  if ("reason" %in% colnames(data)) {
+  if (any("reason" == colnames(data))) {
     reason <- data$reason[!is.na(data$reason)]
     fail_grim  <- length(reason[stringr::str_detect(reason, "GRIM inconsistent")])
     fail_test1 <- length(reason[stringr::str_detect(reason, "test 1")])
@@ -17,6 +17,6 @@ audit.scr_grimmer_map <- function(data) {
       `audit()` will count the reasons for inconsistencies."
     )
   }
-  return(out)
+  out
 }
 
