@@ -2,29 +2,33 @@
 # Helper functions to be mapped in the other helper functions below...
 min_distance_abs_scalar <- function(x) {
   if (any(!is.numeric(x))) {
-    return(NA)
+    return(NA_real_)
   }
   min(abs(x))
 }
 
 min_distance_pos_scalar <- function(x) {
   if (any(!is.numeric(x))) {
-    return(NA)
+    return(NA_real_)
   }
   min(x[x > 0])
 }
 
 min_distance_neg_scalar <- function(x) {
   if (any(!is.numeric(x))) {
-    return(NA)
+    return(NA_real_)
   }
   max(x[x < 0])
 }
 
 # ...namely these ones:
-min_distance_abs <- function(x) purrr::map_dbl(x, min_distance_abs_scalar)
-min_distance_pos <- function(x) purrr::map_dbl(x, min_distance_pos_scalar)
-min_distance_neg <- function(x) purrr::map_dbl(x, min_distance_neg_scalar)
+# min_distance_abs <- function(x) purrr::map_dbl(x, min_distance_abs_scalar)
+# min_distance_pos <- function(x) purrr::map_dbl(x, min_distance_pos_scalar)
+# min_distance_neg <- function(x) purrr::map_dbl(x, min_distance_neg_scalar)
+
+min_distance_abs <- function(x) vapply(x, min_distance_abs_scalar, double(1L))
+min_distance_pos <- function(x) vapply(x, min_distance_pos_scalar, double(1L))
+min_distance_neg <- function(x) vapply(x, min_distance_neg_scalar, double(1L))
 
 
 
@@ -107,7 +111,7 @@ reverse_map_seq <- function(data) {
     dplyr::ungroup() %>%
     dplyr::select(var, scr_index_case)
 
-  out <- data_index_case %>%
+  data_index_case %>%
     tidyr::pivot_wider(
       names_from  = var,
       values_from = scr_index_case,
@@ -115,8 +119,6 @@ reverse_map_seq <- function(data) {
     ) %>%
     tidyr::unnest(cols = everything()) %>%
     tidyr::unnest(cols = everything()) # yes, this is weird
-
-  return(out)
 }
 
 
