@@ -82,6 +82,9 @@ reverse_map_total_n <- function(data) {
   data_reported_1 <- data1[, colnames_reported]
   data_reported_2 <- data2[, colnames_reported]
 
+  n <- data2$n
+  rm(data_reduced, data1, data2, locations1, locations2, ncol_before_n)
+
   colnames(data_reported_1) <- paste0(colnames_reported, "1")
   colnames(data_reported_2) <- paste0(colnames_reported, "2")
 
@@ -89,12 +92,8 @@ reverse_map_total_n <- function(data) {
     rep(each = 2L) %>%
     paste0(c("1", "2"))
 
-  out <- dplyr::bind_cols(data_reported_1, data_reported_2)
-
-  out <- out %>%
+  dplyr::bind_cols(data_reported_1, data_reported_2) %>%
     dplyr::relocate(all_of(colnames_in_order)) %>%
-    dplyr::mutate(n = data2$n)
-
-  return(out)
+    dplyr::mutate(n)
 }
 
