@@ -159,13 +159,11 @@ split_by_parens <- function(data, cols = everything(), check_sep = TRUE,
   # `"parens"` by default and will thus look for parentheses:
   out <- suppressWarnings(dplyr::mutate(data, dplyr::across(
     .cols = all_of(cols_to_select),
-    # .fns = list(before_parens, inside_parens),
     .fns = list(
-      ~ before_parens(string = .x, sep = sep),
-      ~ inside_parens(string = .x, sep = sep)
+      function(x) before_parens(string = x, sep = sep),
+      function(x) inside_parens(string = x, sep = sep)
     ),
     .names = "{.col}_{endings}"
-    # sep = sep
   ), .before = 1L))
 
   # The output is meant to have the same class as the input. Since `out` is not
